AttemptHistoryEntry

Struct AttemptHistoryEntry 

pub struct AttemptHistoryEntry { /* private fields */ }
A deterministic attempt lineage record for a run.

Implementations

Source

impl AttemptHistoryEntry

pub fn attempt_id(&self) -> AttemptId

Returns the attempt identifier.

pub fn started_at(&self) -> u64

Returns the timestamp when the attempt started.

pub fn finished_at(&self) -> Option<u64>

Returns the timestamp when the attempt finished, if any.

pub fn result(&self) -> Option<AttemptResultKind>

Returns canonical attempt result taxonomy, if finished.

pub fn success(&self) -> Option<bool>

Returns whether the attempt succeeded, if finished.

This is a compatibility view over Self::result.

pub fn error(&self) -> Option<&str>

Returns the error message, if any.

pub fn output(&self) -> Option<&[u8]>

Returns the optional opaque output bytes produced by the handler.