Module loader

Module loader 

Snapshot loader interface and file system implementation.

This module provides snapshot loading using a file system backend with versioned decoding for compatibility validation.

The loader reads snapshots that were written using the same framing format as the WAL: version (4 bytes) + length (4 bytes) + CRC-32 (4 bytes) + JSON payload.

Structs

SnapshotFsLoader
A file system backed snapshot loader.

Enums

SnapshotLoaderError
Errors that can occur during snapshot loading.

Traits

SnapshotLoader
A snapshot loader that reads state from storage.