SnapshotFsLoader

Struct SnapshotFsLoader 

pub struct SnapshotFsLoader { /* private fields */ }
A file system backed snapshot loader.

The loader opens a snapshot file and decodes it using the framed binary format written by SnapshotFsWriter:

  • 4 bytes version (currently 4)
  • 4 bytes length of payload
  • 4 bytes CRC-32 of payload
  • JSON-serialized Snapshot

Version checking is performed to ensure compatibility between the writer and loader. If the snapshot version does not match the expected version, SnapshotLoaderError::IncompatibleVersion is returned.

If the snapshot file does not exist, load() will return Ok(None) instead of panicking.

Implementations

Source

impl SnapshotFsLoader

pub fn new(path: PathBuf) -> Self

Creates a new snapshot loader from the given path.

Arguments
  • path - The filesystem path to the snapshot file
pub fn with_version(path: PathBuf, version: u32) -> Self

Creates a new snapshot loader from the given path with a custom version.

This is useful for testing or when the loader needs to support multiple snapshot versions.

Arguments
  • path - The filesystem path to the snapshot file
  • version - The expected snapshot version