Module model

Module model 

Snapshot model types for state persistence.

This module defines the data structures used for snapshot persistence and recovery. Snapshots provide a point-in-time view of the ActionQueue state that can be used to accelerate recovery by reducing the amount of WAL that needs to be replayed.

Structs

Snapshot
A versioned snapshot of the ActionQueue state.
SnapshotActor
Snapshot representation of a registered actor.
SnapshotAttemptHistoryEntry
Snapshot representation of an attempt history entry.
SnapshotBudget
Snapshot representation of a budget allocation and consumption record.
SnapshotCapabilityGrant
Snapshot representation of a capability grant.
SnapshotDependencyDeclaration
Snapshot representation of a dependency declaration.
SnapshotEngineControl
Snapshot representation of engine control projection.
SnapshotLeaseMetadata
Snapshot representation of lease metadata.
SnapshotLedgerEntry
Snapshot representation of a ledger entry.
SnapshotMetadata
Metadata about a snapshot for versioning and compatibility.
SnapshotRoleAssignment
Snapshot representation of a role assignment.
SnapshotRun
A run in the snapshot.
SnapshotRunStateHistoryEntry
Snapshot representation of a run state history entry.
SnapshotSubscription
Snapshot representation of a subscription state record.
SnapshotTask
A task in the snapshot.
SnapshotTenant
Snapshot representation of a tenant.