SnapshotMetadata

Struct SnapshotMetadata 

pub struct SnapshotMetadata {
    pub schema_version: u32,
    pub wal_sequence: u64,
    pub task_count: u64,
    pub run_count: u64,
}
Metadata about a snapshot for versioning and compatibility.

This structure provides extensibility for future snapshot versions while maintaining backward compatibility with existing data.

Fields

schema_version: u32

The schema version of the snapshot format.

This version is incremented when breaking changes are made to the snapshot format. The snapshot loader uses this to determine compatibility.

wal_sequence: u64

The WAL sequence number at the time of the snapshot.

This is the last sequence number that was applied to the state captured in this snapshot. WAL replay should start from sequence number + 1.

task_count: u64

The number of tasks included in this snapshot.

run_count: u64

The number of runs included in this snapshot.