Module writer

Module writer 

Snapshot writer interface and file system implementation.

This module provides snapshot persistence using a file system backend with versioned encoding for compatibility validation.

Structs

SnapshotFsWriter
A file system backed snapshot writer using atomic write-to-temp-then-rename.

Enums

SnapshotFsWriterInitError
Errors that can occur when creating a SnapshotFsWriter.
SnapshotWriterError
Errors that can occur during snapshot writing.

Traits

SnapshotWriter
A snapshot writer that persists state to storage.