WalReader

Trait WalReader 

pub trait WalReader {
    // Required methods
    fn read_next(&mut self) -> Result<Option<WalEvent>, WalReaderError>;
    fn seek_to_sequence(&mut self, sequence: u64) -> Result<(), WalReaderError>;
    fn is_end(&self) -> bool;
}
A reader that can read events from the WAL.

Required Methods

fn read_next(&mut self) -> Result<Option<WalEvent>, WalReaderError>

Read the next event from the WAL.

fn seek_to_sequence(&mut self, sequence: u64) -> Result<(), WalReaderError>

Seek to a specific sequence number.

fn is_end(&self) -> bool

Returns true if the reader is at the end of the WAL.

Implementors