Snapshot model types for state persistence.
This module defines the data structures used for snapshot persistence and recovery. Snapshots provide a point-in-time view of the ActionQueue state that can be used to accelerate recovery by reducing the amount of WAL that needs to be replayed.
Structs
- Snapshot
- A versioned snapshot of the ActionQueue state.
- Snapshot
Actor - Snapshot representation of a registered actor.
- Snapshot
Attempt History Entry - Snapshot representation of an attempt history entry.
- Snapshot
Budget - Snapshot representation of a budget allocation and consumption record.
- Snapshot
Capability Grant - Snapshot representation of a capability grant.
- Snapshot
Dependency Declaration - Snapshot representation of a dependency declaration.
- Snapshot
Engine Control - Snapshot representation of engine control projection.
- Snapshot
Lease Metadata - Snapshot representation of lease metadata.
- Snapshot
Ledger Entry - Snapshot representation of a ledger entry.
- Snapshot
Metadata - Metadata about a snapshot for versioning and compatibility.
- Snapshot
Role Assignment - Snapshot representation of a role assignment.
- Snapshot
Run - A run in the snapshot.
- Snapshot
RunState History Entry - Snapshot representation of a run state history entry.
- Snapshot
Subscription - Snapshot representation of a subscription state record.
- Snapshot
Task - A task in the snapshot.
- Snapshot
Tenant - Snapshot representation of a tenant.