Snapshot writer interface and file system implementation.
This module provides snapshot persistence using a file system backend with versioned encoding for compatibility validation.
Structs
- Snapshot
FsWriter - A file system backed snapshot writer using atomic write-to-temp-then-rename.
Enums
- Snapshot
FsWriter Init Error - Errors that can occur when creating a
SnapshotFsWriter. - Snapshot
Writer Error - Errors that can occur during snapshot writing.
Traits
- Snapshot
Writer - A snapshot writer that persists state to storage.