pub struct WalFsReader { /* private fields */ }Expand description
A file system backed WAL reader.
The reader opens a file and sequentially reads encoded WAL events. Each event is expected to follow the framed binary format from the codec:
- 4 bytes version (currently 2)
- 4 bytes length of payload
- 4 bytes CRC-32 checksum
- payload bytes
If strict framed validation finds corruption, the reader returns
WalReaderError::Corruption with typed offset+reason diagnostics.
Implementations
Sourceimpl WalFsReader
impl WalFsReader
Sourcepub fn new(path: PathBuf) -> Result<Self, WalFsReaderError>
pub fn new(path: PathBuf) -> Result<Self, WalFsReaderError>
Creates a new WAL reader from the given path.
Opens the file in read-only mode and positions the reader at the beginning of the file. The reader will start reading from sequence 0 (or the first event in the file).
Arguments
path- The filesystem path to the WAL file
Errors
Returns WalFsReaderError::IoError if the file cannot be opened.
Sourcepub fn current_sequence(&self) -> u64
pub fn current_sequence(&self) -> u64
Returns the current sequence number being read.